@@ -19,10 +19,12 @@ from lakefs_client.api.auth_api import AuthApi
 from lakefs_client.api.branches_api import BranchesApi
 from lakefs_client.api.commits_api import CommitsApi
 from lakefs_client.api.config_api import ConfigApi
+from lakefs_client.api.experimental_api import ExperimentalApi
 from lakefs_client.api.health_check_api import HealthCheckApi
 from lakefs_client.api.import_api import ImportApi
 from lakefs_client.api.metadata_api import MetadataApi
 from lakefs_client.api.objects_api import ObjectsApi
+from lakefs_client.api.otf_diff_api import OtfDiffApi
 from lakefs_client.api.refs_api import RefsApi
 from lakefs_client.api.repositories_api import RepositoriesApi
 from lakefs_client.api.retention_api import RetentionApi
