@@ -41,6 +41,7 @@ from lakefs_client.model.hook_run_list import HookRunList
 from lakefs_client.model.import_pagination import ImportPagination
 from lakefs_client.model.ingest_range_creation_response import IngestRangeCreationResponse
 from lakefs_client.model.inline_object1 import InlineObject1
+from lakefs_client.model.login_config import LoginConfig
 from lakefs_client.model.login_information import LoginInformation
 from lakefs_client.model.merge import Merge
 from lakefs_client.model.merge_result import MergeResult
@@ -55,6 +56,8 @@ from lakefs_client.model.object_stage_creation import ObjectStageCreation
 from lakefs_client.model.object_stats import ObjectStats
 from lakefs_client.model.object_stats_list import ObjectStatsList
 from lakefs_client.model.object_user_metadata import ObjectUserMetadata
+from lakefs_client.model.otf_diff_entry import OtfDiffEntry
+from lakefs_client.model.otf_diff_list import OtfDiffList
 from lakefs_client.model.pagination import Pagination
 from lakefs_client.model.path_list import PathList
 from lakefs_client.model.policy import Policy
